//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <WScom.h>
#include <WSDimage.h>

WSMFclassInit(WSDimage,WSDres);

WSDimage::WSDimage(){
 _w = 0;
 _h = 0;
 _mode = 0;
// _bitmap = 0;
}

WSDimage::~WSDimage(){
  destroy();
}

//WSCbool WSDimage::isBitmap(){
//  return _bitmap;
//}

long WSDimage::destroyImage(){
  return destroy();
}

long WSDimage::setImageName(char* iname){
   _w = 0;
   _h = 0;
   return setSrc(iname);
}

long WSDimage::setImageWidth(WSCushort w){
  _w = w;
  return WS_NO_ERR;
}

long WSDimage::setImageHeight(WSCushort h){
  _h = h;
  return WS_NO_ERR;
}

WSCushort WSDimage::getImageWidth(){
  getValue1();
  return _w;
}

WSCushort WSDimage::getImageHeight(){
  getValue1();
  return _h;
}
WSCbool WSDimage::getReady(){
  long pix = getValue1();
  if (pix == -1 || pix == 0){
    return False;
  }
  return True; 
}
void WSDimage::setImageMode(WSCulong val){
  _mode = val;
}
WSCulong WSDimage::getImageMode(){
  return _mode;
}
